pub struct SerializedSpan {
pub data: SpanData,
pub generated_from_span: Option<SpanData>,
}Expand description
A Span with its contents laid out, used for serialization and unpacking into a
more readable format.
Fields
data: SpanDataThe source code span; for code coming from a macro expansion, the location of the macro call.
generated_from_span: Option<SpanData>Where the code actually comes from, in case of macro expansion/inlining/etc.